Nagios plugins for dCache
=========================

A collection of nagios plugins to monitor a [dCache][] storage.

Installation
------------

Install the dcache nagios plugins by running:

    pip install dcache-nagios-plugins


Contribute
----------

[Issue Tracker][]
[Source Code][]


License
-------

The project is licensed under the Apache License, Version 2.0.


[dCache]: https://www.dcache.org
[Issue Tracker]:
[Source Code]:










